@@ -5,13 +5,13 @@ from applitools.common.utils.general_utils import DynamicEnumGetter
 
 
 class BrowserType(Enum):
-    CHROME = "chrome-0"
+    CHROME = "chrome"
     CHROME_ONE_VERSION_BACK = "chrome-1"
     CHROME_TWO_VERSIONS_BACK = "chrome-2"
-    FIREFOX = "firefox-0"
+    FIREFOX = "firefox"
     FIREFOX_ONE_VERSION_BACK = "firefox-1"
     FIREFOX_TWO_VERSIONS_BACK = "firefox-2"
-    SAFARI = "safari-0"
+    SAFARI = "safari"
     SAFARI_ONE_VERSION_BACK = "safari-1"
     SAFARI_TWO_VERSIONS_BACK = "safari-2"
     IE_10 = "ie10"
